pub struct DeliveryWorker { /* private fields */ }Expand description
background delivery worker that polls the queue and delivers messages
Implementations
Sourceimpl DeliveryWorker
impl DeliveryWorker
Sourcepub fn new(
config: WorkerConfig,
pool: PgPool,
resolver: TokioResolver,
hostname: String,
) -> Self
pub fn new( config: WorkerConfig, pool: PgPool, resolver: TokioResolver, hostname: String, ) -> Self
Construct a delivery worker with the given config + dependencies.
Sourcepub fn with_dkim(self, dkim: DkimSignConfig) -> Self
pub fn with_dkim(self, dkim: DkimSignConfig) -> Self
Configure DKIM signing for outbound messages.
Sourcepub fn with_event_sender(self, sender: DeliveryEventSender) -> Self
pub fn with_event_sender(self, sender: DeliveryEventSender) -> Self
Attach a DeliveryEventSender callback for external observers.
Sourcepub fn with_valkey(self, url: String) -> Self
pub fn with_valkey(self, url: String) -> Self
Set the Valkey URL to subscribe to queue:notify for fast wakeup.