Module worker

Module worker 

Async delivery worker that drains the queue + dispatches via SMTP (feature-gated).

Structs

DeliveryWorker
background delivery worker that polls the queue and delivers messages
WorkerConfig
Delivery worker configuration.

Enums

TlsPolicy
TLS policy for outbound connections

Functions

group_by_domain
group queued messages by target domain for efficient delivery